# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_DSET_INFO_METADATA = Metadata(
    id="ff980f3e3e262bfc83a21f1bbaca617d1e5c8d48.boutiques",
    name="SurfDsetInfo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfDsetInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_dset_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surf_dset_info(
    runner: Runner | None = None,
) -> SurfDsetInfoOutputs:
    """
    Provides information about surface datasets (DSET).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfDsetInfo.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfDsetInfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_DSET_INFO_METADATA)
    cargs = []
    cargs.append("SurfDsetInfo")
    cargs.append("[OPTIONS]")
    cargs.append("[DATASETS]")
    ret = SurfDsetInfoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_DSET_INFO_METADATA",
    "SurfDsetInfoOutputs",
    "surf_dset_info",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_GET_STANDARD_METADATA = Metadata(
    id="ff1d680aaa25c24537aacd55f170f3dcacf76df6.boutiques",
    name="fsl_get_standard",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslGetStandardOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_get_standard(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsl_get_standard(
    image_type: typing.Literal["whole_head", "brain", "brain_mask"],
    resolution: float | None = None,
    verbose_flag: bool = False,
    version_flag: bool = False,
    runner: Runner | None = None,
) -> FslGetStandardOutputs:
    """
    Generate paths to FSL standard space images.
    
    Args:
        image_type: Image type - one of 'whole_head' (the default), 'brain', or\
            'brain_mask'.
        resolution: Desired isotropic resolution in millimetres.
        verbose_flag: Output more information.
        version_flag: Print version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslGetStandardOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_GET_STANDARD_METADATA)
    cargs = []
    cargs.append("fsl_get_standard")
    cargs.append(image_type)
    if resolution is not None:
        cargs.extend([
            "-r",
            str(resolution)
        ])
    if verbose_flag:
        cargs.append("-v")
    if version_flag:
        cargs.append("-V")
    ret = FslGetStandardOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_GET_STANDARD_METADATA",
    "FslGetStandardOutputs",
    "fsl_get_standard",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MANN_WHITNEY_METADATA = Metadata(
    id="bc4e85f7d5f25d592e756262956031e23953be5a.boutiques",
    name="3dMannWhitney",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMannWhitneyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_mann_whitney(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Output files for the estimated population delta and Wilcoxon-Mann-Whitney
    statistics."""


def v_3d_mann_whitney(
    dset1_x: list[str],
    dset2_y: list[str],
    output_prefix: str,
    workmem: int | None = None,
    voxel_num: int | None = None,
    runner: Runner | None = None,
) -> V3dMannWhitneyOutputs:
    """
    Performs nonparametric Mann-Whitney two-sample test.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dMannWhitney.html
    
    Args:
        dset1_x: Data set for X observations. Must specify 1 and only 1\
            sub-brick.
        dset2_y: Data set for Y observations. Must specify 1 and only 1\
            sub-brick.
        output_prefix: Estimated population delta and Wilcoxon-Mann-Whitney\
            statistics written to file.
        workmem: Number of megabytes of RAM to use for statistical workspace.
        voxel_num: Screen output for voxel # num.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMannWhitneyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MANN_WHITNEY_METADATA)
    cargs = []
    cargs.append("3dMannWhitney")
    cargs.extend([
        "-dset 1",
        *dset1_x
    ])
    cargs.extend([
        "-dset 2",
        *dset2_y
    ])
    cargs.extend([
        "-out",
        output_prefix
    ])
    if workmem is not None:
        cargs.extend([
            "-workmem",
            str(workmem)
        ])
    if voxel_num is not None:
        cargs.extend([
            "-voxel",
            str(voxel_num)
        ])
    ret = V3dMannWhitneyOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(output_prefix + "*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMannWhitneyOutputs",
    "V_3D_MANN_WHITNEY_METADATA",
    "v_3d_mann_whitney",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DISTANCEMAP_METADATA = Metadata(
    id="dba579c3fbd3d6218ecbc9a45322438109192f08.boutiques",
    name="distancemap",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class DistancemapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `distancemap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_distancemap: OutputPathType
    """Output distance map image"""
    output_local_maxima: OutputPathType
    """Output local maxima image"""
    output_segmented_image: OutputPathType
    """Output segmented distance map image"""


def distancemap(
    runner: Runner | None = None,
) -> DistancemapOutputs:
    """
    A tool to calculate distance maps using FSL.
    
    Author: University of Oxford (Mark Jenkinson)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FSL
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DistancemapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DISTANCEMAP_METADATA)
    cargs = []
    cargs.append("distancemap")
    cargs.append("[OPTIONS]")
    ret = DistancemapOutputs(
        root=execution.output_file("."),
        output_distancemap=execution.output_file("[OUTPUT_IMAGE]"),
        output_local_maxima=execution.output_file("[LOCAL_MAXIMA_IMAGE]"),
        output_segmented_image=execution.output_file("[SEGMENTED_IMAGE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DISTANCEMAP_METADATA",
    "DistancemapOutputs",
    "distancemap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_5TTGEN_METADATA = Metadata(
    id="e1c8721cf951c39ed38887df51b196592e09eda2.boutiques",
    name="5ttgen",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


class V5ttgenFreesurferOutputs(typing.NamedTuple):
    """
    Output object returned when calling `V5ttgenFreesurfer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """The output 5TT image"""


@dataclasses.dataclass
class V5ttgenFreesurfer:
    """
    Generate the 5TT image based on a FreeSurfer parcellation image.
    """
    input_: InputPathType
    """The input FreeSurfer parcellation image (any image containing 'aseg' in
    its name)"""
    output: InputPathType
    """The output 5TT image"""
    lut: InputPathType | None = None
    """Manually provide path to the lookup table on which the input parcellation
    image is based (e.g. FreeSurferColorLUT.txt)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("freesurfer")
        cargs.append(execution.input_file(self.input_))
        cargs.append(execution.input_file(self.output))
        if self.lut is not None:
            cargs.extend([
                "-lut",
                execution.input_file(self.lut)
            ])
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> V5ttgenFreesurferOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `V5ttgenFreesurferOutputs`).
        """
        ret = V5ttgenFreesurferOutputs(
            root=execution.output_file("."),
            output=execution.output_file(pathlib.Path(self.output).name),
        )
        return ret


class V5ttgenFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `V5ttgenFsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """The output 5TT image"""


@dataclasses.dataclass
class V5ttgenFsl:
    """
    Use FSL commands to generate the 5TT image based on a T1-weighted image.
    """
    input_: InputPathType
    """The input T1-weighted image"""
    output: InputPathType
    """The output 5TT image"""
    t2: InputPathType | None = None
    """Provide a T2-weighted image in addition to the default T1-weighted image;
    this will be used as a second input to FSL FAST"""
    mask: InputPathType | None = None
    """Manually provide a brain mask, rather than deriving one in the script"""
    premasked: bool = False
    """Indicate that brain masking has already been applied to the input
    image"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("fsl")
        cargs.append(execution.input_file(self.input_))
        cargs.append(execution.input_file(self.output))
        if self.t2 is not None:
            cargs.extend([
                "-t2",
                execution.input_file(self.t2)
            ])
        if self.mask is not None:
            cargs.extend([
                "-mask",
                execution.input_file(self.mask)
            ])
        if self.premasked:
            cargs.append("-premasked")
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> V5ttgenFslOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `V5ttgenFslOutputs`).
        """
        ret = V5ttgenFslOutputs(
            root=execution.output_file("."),
            output=execution.output_file(pathlib.Path(self.output).name),
        )
        return ret


class V5ttgenGifOutputs(typing.NamedTuple):
    """
    Output object returned when calling `V5ttgenGif(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """The output 5TT image"""


@dataclasses.dataclass
class V5ttgenGif:
    """
    Generate the 5TT image based on a Geodesic Information Flow (GIF)
    segmentation image.
    """
    input_: InputPathType
    """The input Geodesic Information Flow (GIF) segmentation image"""
    output: InputPathType
    """The output 5TT image"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("gif")
        cargs.append(execution.input_file(self.input_))
        cargs.append(execution.input_file(self.output))
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> V5ttgenGifOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `V5ttgenGifOutputs`).
        """
        ret = V5ttgenGifOutputs(
            root=execution.output_file("."),
            output=execution.output_file(pathlib.Path(self.output).name),
        )
        return ret


class V5ttgenHsvsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `V5ttgenHsvs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType
    """The output 5TT image"""


@dataclasses.dataclass
class V5ttgenHsvs:
    """
    Generate a 5TT image based on Hybrid Surface and Volume Segmentation (HSVS),
    using FreeSurfer and FSL tools.
    """
    input_: InputPathType
    """The input FreeSurfer subject directory"""
    output: InputPathType
    """The output 5TT image"""
    template: InputPathType | None = None
    """Provide an image that will form the template for the generated 5TT
    image"""
    hippocampi: typing.Literal["subfields", "first", "aseg"] | None = None
    """Select method to be used for hippocampi (& amygdalae) segmentation;
    options are: subfields,first,aseg"""
    thalami: typing.Literal["nuclei", "first", "aseg"] | None = None
    """Select method to be used for thalamic segmentation; options are:
    nuclei,first,aseg"""
    white_stem: bool = False
    """Classify the brainstem as white matter"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("hsvs")
        cargs.append(execution.input_file(self.input_))
        cargs.append(execution.input_file(self.output))
        if self.template is not None:
            cargs.extend([
                "-template",
                execution.input_file(self.template)
            ])
        if self.hippocampi is not None:
            cargs.append(self.hippocampi)
        if self.thalami is not None:
            cargs.append(self.thalami)
        if self.white_stem:
            cargs.append("-white_stem")
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> V5ttgenHsvsOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `V5ttgenHsvsOutputs`).
        """
        ret = V5ttgenHsvsOutputs(
            root=execution.output_file("."),
            output=execution.output_file(pathlib.Path(self.output).name),
        )
        return ret


@dataclasses.dataclass
class V5ttgenConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class V5ttgenOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_5ttgen(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    algorithm: typing.Union[V5ttgenFreesurferOutputs, V5ttgenFslOutputs, V5ttgenGifOutputs, V5ttgenHsvsOutputs]
    """Outputs from `V5ttgenFreesurfer` or `V5ttgenFsl` or `V5ttgenGif` or
    `V5ttgenHsvs`."""


def v_5ttgen(
    algorithm: typing.Union[V5ttgenFreesurfer, V5ttgenFsl, V5ttgenGif, V5ttgenHsvs],
    nocrop: bool = False,
    sgm_amyg_hipp: bool = False,
    nocleanup: bool = False,
    scratch: str | None = None,
    continue_: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[V5ttgenConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> V5ttgenOutputs:
    """
    Generate a 5TT image suitable for ACT.
    
    5ttgen acts as a 'master' script for generating a five-tissue-type (5TT)
    segmented tissue image suitable for use in Anatomically-Constrained
    Tractography (ACT). A range of different algorithms are available for
    completing this task. When using this script, the name of the algorithm to
    be used must appear as the first argument on the command-line after
    '5ttgen'. The subsequent compulsory arguments and options available depend
    on the particular algorithm being invoked.
    Each algorithm available also has its own help page, including necessary
    references; e.g. to see the help page of the 'fsl' algorithm, type '5ttgen
    fsl'.
    
    Author: Robert E. Smith (robert.smith@florey.edu.au)
    
    URL: https://mrtrix.readthedocs.io/en/3.0.4/reference/commands/5ttgen.html
    
    Args:
        algorithm: Select the algorithm to be used to complete the script\
            operation; additional details and options become available once an\
            algorithm is nominated. Options are: freesurfer, fsl, gif, hsvs.
        nocrop: Do NOT crop the resulting 5TT image to reduce its size (keep\
            the same dimensions as the input image).
        sgm_amyg_hipp: Represent the amygdalae and hippocampi as sub-cortical\
            grey matter in the 5TT image.
        nocleanup: do not delete intermediate files during script execution,\
            and do not delete scratch directory at script completion.
        scratch: manually specify the path in which to generate the scratch\
            directory.
        continue_: continue the script from a previous execution; must provide\
            the scratch directory path, and the name of the last\
            successfully-generated file.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V5ttgenOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_5TTGEN_METADATA)
    cargs = []
    cargs.append("5ttgen")
    cargs.extend(algorithm.run(execution))
    if nocrop:
        cargs.append("-nocrop")
    if sgm_amyg_hipp:
        cargs.append("-sgm_amyg_hipp")
    if nocleanup:
        cargs.append("-nocleanup")
    if scratch is not None:
        cargs.extend([
            "-scratch",
            scratch
        ])
    if continue_ is not None:
        cargs.extend([
            "-continue",
            continue_
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    ret = V5ttgenOutputs(
        root=execution.output_file("."),
        algorithm=algorithm.outputs(execution),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V5ttgenConfig",
    "V5ttgenFreesurfer",
    "V5ttgenFreesurferOutputs",
    "V5ttgenFsl",
    "V5ttgenFslOutputs",
    "V5ttgenGif",
    "V5ttgenGifOutputs",
    "V5ttgenHsvs",
    "V5ttgenHsvsOutputs",
    "V5ttgenOutputs",
    "V_5TTGEN_METADATA",
    "v_5ttgen",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EG_MAIN_CHRONO_PY_METADATA = Metadata(
    id="0b65e95e874d7a0a8d6d43a4d6a2803648fb76e7.boutiques",
    name="eg_main_chrono.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class EgMainChronoPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `eg_main_chrono_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def eg_main_chrono_py(
    help_: bool = False,
    history: bool = False,
    show_valid_options: bool = False,
    version: bool = False,
    verbosity_level: str | None = None,
    runner: Runner | None = None,
) -> EgMainChronoPyOutputs:
    """
    A sample main Python program to run on top of some library.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/eg_main_chrono.py.html
    
    Args:
        help_: Show help message.
        history: Show module history.
        show_valid_options: List valid options.
        version: Show current version.
        verbosity_level: Set the verbosity level.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EgMainChronoPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EG_MAIN_CHRONO_PY_METADATA)
    cargs = []
    cargs.append("eg_main_chrono.py")
    if help_:
        cargs.append("-help")
    if history:
        cargs.append("-hist")
    if show_valid_options:
        cargs.append("-show_valid_opts")
    if version:
        cargs.append("-ver")
    if verbosity_level is not None:
        cargs.extend([
            "-verb",
            verbosity_level
        ])
    ret = EgMainChronoPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EG_MAIN_CHRONO_PY_METADATA",
    "EgMainChronoPyOutputs",
    "eg_main_chrono_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DDOT_BETA_METADATA = Metadata(
    id="a2c6b419e5021ee83955e8440e5538da08222a79.boutiques",
    name="3ddot_beta",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3ddotBetaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3ddot_beta(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output text file containing the correlation-like matrix"""


def v_3ddot_beta(
    input_file: InputPathType,
    prefix: str,
    doeta2: bool = False,
    mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3ddotBetaOutputs:
    """
    Beta version of updating 3ddot, currently only performing eta2 tests and
    outputting a full matrix to a text file.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3ddot_beta.html
    
    Args:
        input_file: Input file with N bricks.
        prefix: Output prefix for the result file.
        doeta2: Required flag for performing eta2 tests.
        mask: Optional mask file within which to take values.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3ddotBetaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DDOT_BETA_METADATA)
    cargs = []
    cargs.append("3ddot_beta")
    cargs.append("-input")
    cargs.append(execution.input_file(input_file))
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        prefix
    ])
    if doeta2:
        cargs.append("-doeta2")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    ret = V3ddotBetaOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + "_eta2.dat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3ddotBetaOutputs",
    "V_3DDOT_BETA_METADATA",
    "v_3ddot_beta",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_CLUSTERIZE_METADATA = Metadata(
    id="5bc26198ecd1ed079d05ba6875036e96b7ea8faf.boutiques",
    name="3dClusterize",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dClusterizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_clusterize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_map_file: OutputPathType | None
    """Output map of cluster ROIs"""
    out_data_file: OutputPathType | None
    """Cluster-masked version of the data volume"""
    out_mask_file: OutputPathType | None
    """Utilized mask dataset"""


def v_3d_clusterize(
    inset: InputPathType,
    ithr: str,
    nn: int,
    mask: InputPathType | None = None,
    mask_from_hdr: bool = False,
    out_mask: str | None = None,
    idat: str | None = None,
    onesided: str | None = None,
    twosided: str | None = None,
    bisided: str | None = None,
    within_range: str | None = None,
    clust_nvox: int | None = None,
    clust_vol: int | None = None,
    pref_map: str | None = None,
    pref_dat: str | None = None,
    one_d_format: bool = False,
    no_one_d_format: bool = False,
    summarize: bool = False,
    nosum: bool = False,
    quiet: bool = False,
    outvol_if_no_clust: bool = False,
    orient: str | None = None,
    abs_table_data: bool = False,
    binary: bool = False,
    runner: Runner | None = None,
) -> V3dClusterizeOutputs:
    """
    A tool for voxelwise thresholding and clusterizing of datasets.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dClusterize.html
    
    Args:
        inset: Load in a dataset for thresholding and clusterizing.
        ithr: Specify the sub-brick to use as the threshold source.
        nn: Specify the number of voxel neighbors (1: 6, 2: 18, 3: 26).
        mask: Load in a dataset to use as a mask.
        mask_from_hdr: Use internal mask from dataset header.
        out_mask: Specify to dump the utilized mask as a dataset.
        idat: Specify the sub-brick to use as the data source.
        onesided: Perform one-sided testing.
        twosided: Perform two-sided testing.
        bisided: Perform bisided testing.
        within_range: Keep values within the range [AA, BB].
        clust_nvox: Specify the minimum cluster size in terms of number of\
            voxels.
        clust_vol: Specify the minimum cluster size by volume in microliters.
        pref_map: Prefix/filename of the output map of cluster ROIs.
        pref_dat: Output a cluster-masked version of the data volume.
        one_d_format: Write output in 1D format.
        no_one_d_format: Do not write output in 1D format.
        summarize: Write out only the total nonzero voxel count and volume for\
            each dataset.
        nosum: Suppress printout of the totals.
        quiet: Suppress all non-essential output.
        outvol_if_no_clust: Output an empty volume if no clusters are found.
        orient: Coordinate order in the output report table (default: RAI).
        abs_table_data: Use absolute values for mean and SEM in report table.
        binary: Turn output map of cluster ROIs into a binary mask.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dClusterizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_CLUSTERIZE_METADATA)
    cargs = []
    cargs.append("3dClusterize")
    cargs.extend([
        "-inset",
        execution.input_file(inset)
    ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if mask_from_hdr:
        cargs.append("-mask_from_hdr")
    if out_mask is not None:
        cargs.extend([
            "-out_mask",
            out_mask
        ])
    cargs.extend([
        "-ithr",
        ithr
    ])
    if idat is not None:
        cargs.extend([
            "-idat",
            idat
        ])
    if onesided is not None:
        cargs.extend([
            "-1sided",
            onesided
        ])
    if twosided is not None:
        cargs.extend([
            "-2sided",
            twosided
        ])
    if bisided is not None:
        cargs.extend([
            "-bisided",
            bisided
        ])
    if within_range is not None:
        cargs.extend([
            "-within_range",
            within_range
        ])
    cargs.extend([
        "-NN",
        str(nn)
    ])
    if clust_nvox is not None:
        cargs.extend([
            "-clust_nvox",
            str(clust_nvox)
        ])
    if clust_vol is not None:
        cargs.extend([
            "-clust_vol",
            str(clust_vol)
        ])
    if pref_map is not None:
        cargs.extend([
            "-pref_map",
            pref_map
        ])
    if pref_dat is not None:
        cargs.extend([
            "-pref_dat",
            pref_dat
        ])
    if one_d_format:
        cargs.append("-1Dformat")
    if no_one_d_format:
        cargs.append("-no_1Dformat")
    if summarize:
        cargs.append("-summarize")
    if nosum:
        cargs.append("-nosum")
    if quiet:
        cargs.append("-quiet")
    if outvol_if_no_clust:
        cargs.append("-outvol_if_no_clust")
    if orient is not None:
        cargs.extend([
            "-orient",
            orient
        ])
    if abs_table_data:
        cargs.append("-abs_table_data")
    if binary:
        cargs.append("-binary")
    ret = V3dClusterizeOutputs(
        root=execution.output_file("."),
        out_map_file=execution.output_file(pref_map + "+orig.HEAD") if (pref_map is not None) else None,
        out_data_file=execution.output_file(pref_dat + "+orig.HEAD") if (pref_dat is not None) else None,
        out_mask_file=execution.output_file(out_mask + "+orig.HEAD") if (out_mask is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dClusterizeOutputs",
    "V_3D_CLUSTERIZE_METADATA",
    "v_3d_clusterize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ANIMAL_WARPER_METADATA = Metadata(
    id="f373bc7e1633539a38d1306872d0f169bc4fc59c.boutiques",
    name="@animal_warper",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAnimalWarperOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__animal_warper(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    warp2std: OutputPathType
    """input dataset nonlinearly warped to template"""
    qc_image_initial: OutputPathType
    """initial QC image montage showing overlap of source and base dataset"""
    qc_image_initial_sh: OutputPathType
    """initial QC image montage after shifting centers of source and base
    dataset"""
    dset_followers_out: OutputPathType
    """copy(s) of -dset_followers mapped to template space"""
    roidset_followers_out: OutputPathType
    """copy(s) of -roidset_followers mapped to template space"""
    animal_outs_guide: OutputPathType
    """guide to data in output directory"""


def v__animal_warper(
    input_file: InputPathType,
    base_template: InputPathType,
    output_dir: str,
    brainmask: InputPathType | None = None,
    atlases: list[InputPathType] | None = None,
    atlas_followers: list[InputPathType] | None = None,
    seg_followers: list[InputPathType] | None = None,
    template_followers: list[InputPathType] | None = None,
    dset_followers: list[InputPathType] | None = None,
    roidset_followers: list[InputPathType] | None = None,
    input_abbrev: str | None = None,
    base_abbrev: str | None = None,
    atlas_abbrevs: list[str] | None = None,
    template_abbrevs: list[str] | None = None,
    seg_abbrevs: list[str] | None = None,
    dset_abbrevs: list[str] | None = None,
    roidset_abbrevs: list[str] | None = None,
    align_centers_meth: str | None = None,
    aff_move_opt: str | None = None,
    cost: str | None = None,
    maxlev: float | None = None,
    no_surfaces: bool = False,
    feature_size: float | None = None,
    supersize: bool = False,
    init_scale: float | None = None,
    mode_smooth_size: float | None = None,
    mode_smooth_replacement_off: bool = False,
    center_out: str | None = None,
    align_type: str | None = None,
    extra_qw_opts: str | None = None,
    keep_temp: bool = False,
    version: bool = False,
    ok_to_exist: bool = False,
    echo: bool = False,
    runner: Runner | None = None,
) -> VAnimalWarperOutputs:
    """
    Align a subject structural dataset to a template and perform several
    post-alignment operations.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@animal_warper.html
    
    Args:
        input_file: input dataset to align to base template.
        base_template: base dataset (template) to align with.
        output_dir: output directory where all processing will be performed.
        brainmask: provide a brainmask in the base template space.
        atlases: one or more atlas datasets in the base volume space.
        atlas_followers: one or more atlas datasets in the base volume space.
        seg_followers: one or more segmentation datasets in the base volume\
            space.
        template_followers: one or more datasets in the template volume space.
        dset_followers: one or more datasets in the input volume space.
        roidset_followers: one or more (int-valued) datasets in the input\
            volume space.
        input_abbrev: specify abbreviation for input dataset.
        base_abbrev: specify abbreviation for base dataset.
        atlas_abbrevs: specify an abbreviation for each atlas follower dataset.
        template_abbrevs: specify an abbreviation for each template follower\
            dataset.
        seg_abbrevs: specify an abbreviation for each segmentation follower\
            dataset.
        dset_abbrevs: specify an abbreviation for each dataset follower dataset.
        roidset_abbrevs: specify an abbreviation for each ROI dataset follower\
            dataset.
        align_centers_meth: center alignment method to use.
        aff_move_opt: alignment movement options for affine alignment step.
        cost: cost function for affine and nonlinear alignment.
        maxlev: Max level for nonlinear warping. Final patch size is determined\
            based on this value.
        no_surfaces: Do not make surfaces for atlas regions in native space.
        feature_size: Set feature size for affine alignment (in mm).
        supersize: Allow up to 50% size difference between subject and template.
        init_scale: Approximate length ratio of input to template for initial\
            scaling.
        mode_smooth_size: Modal smoothing kernel size in voxels.
        mode_smooth_replacement_off: Turn off replacement in modal smoothing.
        center_out: Center native-space output to native original space or\
            template space center-shifted.
        align_type: Specify level of alignment.
        extra_qw_opts: Additional options to add to existing options for\
            3dQwarp.
        keep_temp: Keep temporary files including awpy directory and other\
            intermediate datasets.
        version: Display the program version.
        ok_to_exist: Reuse and do not overwrite existing datasets.
        echo: Copy all commands being run into the terminal.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAnimalWarperOutputs`).
    """
    if maxlev is not None and not (0 <= maxlev <= 11): 
        raise ValueError(f"'maxlev' must be between 0 <= x <= 11 but was {maxlev}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ANIMAL_WARPER_METADATA)
    cargs = []
    cargs.append("animal_warper")
    cargs.append(execution.input_file(input_file))
    cargs.append(execution.input_file(base_template))
    cargs.append(output_dir)
    if brainmask is not None:
        cargs.append(execution.input_file(brainmask))
    if atlases is not None:
        cargs.extend([
            "-atlas",
            *[execution.input_file(f) for f in atlases]
        ])
    if atlas_followers is not None:
        cargs.extend([
            "-atlas_followers",
            *[execution.input_file(f) for f in atlas_followers]
        ])
    if seg_followers is not None:
        cargs.extend([
            "-seg_followers",
            *[execution.input_file(f) for f in seg_followers]
        ])
    if template_followers is not None:
        cargs.extend([
            "-template_followers",
            *[execution.input_file(f) for f in template_followers]
        ])
    if dset_followers is not None:
        cargs.extend([
            "-dset_followers",
            *[execution.input_file(f) for f in dset_followers]
        ])
    if roidset_followers is not None:
        cargs.extend([
            "-roidset_followers",
            *[execution.input_file(f) for f in roidset_followers]
        ])
    if input_abbrev is not None:
        cargs.extend([
            "-input_abbrev",
            input_abbrev
        ])
    if base_abbrev is not None:
        cargs.extend([
            "-base_abbrev",
            base_abbrev
        ])
    if atlas_abbrevs is not None:
        cargs.extend([
            "-atlas_abbrevs",
            *atlas_abbrevs
        ])
    if template_abbrevs is not None:
        cargs.extend([
            "-template_abbrevs",
            *template_abbrevs
        ])
    if seg_abbrevs is not None:
        cargs.extend([
            "-seg_abbrevs",
            *seg_abbrevs
        ])
    if dset_abbrevs is not None:
        cargs.extend([
            "-dset_abbrevs",
            *dset_abbrevs
        ])
    if roidset_abbrevs is not None:
        cargs.extend([
            "-roidset_abbrevs",
            *roidset_abbrevs
        ])
    if align_centers_meth is not None:
        cargs.extend([
            "-align_centers_meth",
            align_centers_meth
        ])
    if aff_move_opt is not None:
        cargs.extend([
            "-aff_move_opt",
            aff_move_opt
        ])
    if cost is not None:
        cargs.extend([
            "-cost",
            cost
        ])
    if maxlev is not None:
        cargs.extend([
            "-maxlev",
            str(maxlev)
        ])
    if no_surfaces:
        cargs.append("-no_surfaces")
    if feature_size is not None:
        cargs.extend([
            "-feature_size",
            str(feature_size)
        ])
    if supersize:
        cargs.append("-supersize")
    if init_scale is not None:
        cargs.extend([
            "-init_scale",
            str(init_scale)
        ])
    if mode_smooth_size is not None:
        cargs.extend([
            "-mode_smooth_size",
            str(mode_smooth_size)
        ])
    if mode_smooth_replacement_off:
        cargs.append("-mode_smooth_replacement_off")
    if center_out is not None:
        cargs.extend([
            "-center_out",
            center_out
        ])
    if align_type is not None:
        cargs.extend([
            "-align_type",
            align_type
        ])
    if extra_qw_opts is not None:
        cargs.extend([
            "-extra_qw_opts",
            extra_qw_opts
        ])
    if keep_temp:
        cargs.append("-keep_temp")
    if version:
        cargs.append("-ver")
    if ok_to_exist:
        cargs.append("-ok_to_exist")
    if echo:
        cargs.append("-echo")
    ret = VAnimalWarperOutputs(
        root=execution.output_file("."),
        warp2std=execution.output_file("aw_results/" + pathlib.Path(input_file).name + "_warp2std.nii.gz"),
        qc_image_initial=execution.output_file("aw_results/init_qc_00.input+base*.jpg"),
        qc_image_initial_sh=execution.output_file("aw_results/init_qc_01.input_sh+base*.jpg"),
        dset_followers_out=execution.output_file("aw_results/DSET_FOLL.nii.gz"),
        roidset_followers_out=execution.output_file("aw_results/ROIDSET_FOLL.nii.gz"),
        animal_outs_guide=execution.output_file("aw_results/animal_outs.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAnimalWarperOutputs",
    "V__ANIMAL_WARPER_METADATA",
    "v__animal_warper",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SLICESMASK_METADATA = Metadata(
    id="640ba5ea73920106e5860ec2243290d406631e43.boutiques",
    name="slicesmask",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SlicesmaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `slicesmask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    masked_output: OutputPathType
    """The output file resulting from applying the mask"""


def slicesmask(
    image: InputPathType,
    mask: InputPathType,
    output: str,
    runner: Runner | None = None,
) -> SlicesmaskOutputs:
    """
    Tool for masking slices from an image using a mask.
    
    Author: Unknown
    
    Args:
        image: Input image file.
        mask: Mask file.
        output: Output file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SlicesmaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SLICESMASK_METADATA)
    cargs = []
    cargs.append("slicesmask")
    cargs.append(execution.input_file(image))
    cargs.append(execution.input_file(mask))
    cargs.append(output)
    ret = SlicesmaskOutputs(
        root=execution.output_file("."),
        masked_output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SLICESMASK_METADATA",
    "SlicesmaskOutputs",
    "slicesmask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRDUMP_METADATA = Metadata(
    id="72143b13267a2d4630514d2fb7c746bfc55b6a4a.boutiques",
    name="mrdump",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class MrdumpConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class MrdumpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mrdump(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType | None
    """the (optional) output text file."""


def mrdump(
    input_: InputPathType,
    mask: InputPathType | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[MrdumpConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    output: str | None = None,
    runner: Runner | None = None,
) -> MrdumpOutputs:
    """
    Print out the values within an image.
    
    If no destination file is specified, the voxel locations will be printed to
    stdout.
    
    References:
    
    .
    
    Author: Robert E. Smith (robert.smith@florey.edu.au)
    
    URL: https://mrtrix.readthedocs.io/en/latest/reference/commands/mrdump.html
    
    Args:
        input_: the input image.
        mask: only write the image values within voxels specified by a mask\
            image.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        output: the (optional) output text file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrdumpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRDUMP_METADATA)
    cargs = []
    cargs.append("mrdump")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(input_))
    if output is not None:
        cargs.append(output)
    ret = MrdumpOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output) if (output is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRDUMP_METADATA",
    "MrdumpConfig",
    "MrdumpOutputs",
    "mrdump",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_DECONVOLVE_METADATA = Metadata(
    id="5e4431741fecb6d1d8debcf228eba178f6aa57f6.boutiques",
    name="3dDeconvolve",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dDeconvolveOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_deconvolve(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    bucket_output: OutputPathType
    """Main output bucket dataset in AFNI format."""
    cbucket_output: OutputPathType
    """Regression coefficients stored in a dataset."""
    iresp_output: OutputPathType
    """Estimated Impulse Response dataset."""
    fitts_output: OutputPathType
    """Fitted Time Series dataset in AFNI format."""
    x1d_file: OutputPathType
    """X-matrix output file in .1D format."""


def v_3d_deconvolve(
    input_dataset: InputPathType,
    mask_dataset: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dDeconvolveOutputs:
    """
    Program to calculate the deconvolution of a measurement 3D+time dataset with a
    specified input stimulus time series.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dDeconvolve.html
    
    Args:
        input_dataset: Filename of 3D+time input dataset.
        mask_dataset: Filename of 3D mask dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dDeconvolveOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_DECONVOLVE_METADATA)
    cargs = []
    cargs.append("3dDeconvolve")
    cargs.extend([
        "-input",
        execution.input_file(input_dataset)
    ])
    if mask_dataset is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_dataset)
        ])
    cargs.append("[OPTIONS...]")
    ret = V3dDeconvolveOutputs(
        root=execution.output_file("."),
        bucket_output=execution.output_file("[BUCKET].HEAD"),
        cbucket_output=execution.output_file("[CBUCKET].HEAD"),
        iresp_output=execution.output_file("[IRESP].HEAD"),
        fitts_output=execution.output_file("[FITTS].HEAD"),
        x1d_file=execution.output_file("[X1D].1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dDeconvolveOutputs",
    "V_3D_DECONVOLVE_METADATA",
    "v_3d_deconvolve",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_PROC_CONNEC_VIS_METADATA = Metadata(
    id="b1bc18b7b682b800fdd69b9ca77f86dc0c61bdab.boutiques",
    name="fat_proc_connec_vis",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatProcConnecVisOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_proc_connec_vis(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cmd_txt: OutputPathType
    """Command text file output"""
    tcat_file: OutputPathType
    """Concatenated ROI masks multibrick file from the -output_tcat flag"""
    tstat_file: OutputPathType
    """Single brick file from 3dTstat operation on the tcat dataset, produced by
    the -output_tstat flag"""


def fat_proc_connec_vis(
    in_rois: str,
    prefix: str,
    runner: Runner | None = None,
) -> FatProcConnecVisOutputs:
    """
    This program is for visualizing the volumetric output of tracking, mainly for
    the '-dump_rois ...' from 3dTrackID. It creates surface-ized views of the
    separate white matter connection maps (WMCs) which can be viewed simultaneously
    in 3D with SUMA.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/fat_proc_connec_vis.html
    
    Args:
        in_rois: List of separate files, each with a single ROI volume mask;\
            can include wildcards, etc. to specify the list.
        prefix: Directory to contain the output files: *cmd.txt and surface\
            files such as *.gii and *.niml.dset; the namebase of files within this\
            directory will be the default for the program, 'wmc'. The value PPP can\
            contain parts of a path in it.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatProcConnecVisOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_PROC_CONNEC_VIS_METADATA)
    cargs = []
    cargs.append("fat_proc_connec_vis")
    cargs.append("-in_rois")
    cargs.append(in_rois)
    cargs.append("-prefix")
    cargs.append(prefix)
    cargs.append("[--prefix_file")
    cargs.append("FFF]")
    cargs.append("[--tsmoo_kpb")
    cargs.append("KPB]")
    cargs.append("[--tsmoo_niter")
    cargs.append("NITER]")
    cargs.append("[--iso_opt")
    cargs.append("ISO_OPT]")
    cargs.append("[--trackid_no_or]")
    cargs.append("[--output_tcat]")
    cargs.append("[--output_tstat]")
    cargs.append("[--wdir")
    cargs.append("WWW]")
    cargs.append("[--no_clean]")
    ret = FatProcConnecVisOutputs(
        root=execution.output_file("."),
        cmd_txt=execution.output_file(prefix + "_cmd.txt"),
        tcat_file=execution.output_file(prefix + "_tcat.nii.gz"),
        tstat_file=execution.output_file(prefix + "_tstat.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_PROC_CONNEC_VIS_METADATA",
    "FatProcConnecVisOutputs",
    "fat_proc_connec_vis",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TCKGLOBAL_METADATA = Metadata(
    id="9a2dbc3f27bab5e95b5061f6292c2ac390832c5c.boutiques",
    name="tckglobal",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class TckglobalRiso:
    """
    set one or more isotropic response functions. (multiple allowed).
    """
    response: InputPathType
    """set one or more isotropic response functions. (multiple allowed)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-riso")
        cargs.append(execution.input_file(self.response))
        return cargs


@dataclasses.dataclass
class TckglobalConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class TckglobalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tckglobal(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    tracks: OutputPathType
    """the output file containing the tracks generated."""
    fod: OutputPathType | None
    """Predicted fibre orientation distribution function (fODF).
    This fODF is estimated as part of the global track optimization, and
    therefore incorporates the spatial regularization that it imposes.
    Internally, the fODF is represented as a discrete sum of apodized point
    spread functions (aPSF) oriented along the directions of all particles in
    the voxel, used to predict the DWI signal from the particle configuration.
    """
    fiso: OutputPathType | None
    """Predicted isotropic fractions of the tissues for which response functions
    were provided with -riso. Typically, these are CSF and GM. """
    eext: OutputPathType | None
    """Residual external energy in every voxel. """
    etrend: OutputPathType | None
    """internal and external energy trend and cooling statistics. """


def tckglobal(
    source: InputPathType,
    response: InputPathType,
    tracks: str,
    grad: InputPathType | None = None,
    mask: InputPathType | None = None,
    riso: list[TckglobalRiso] | None = None,
    lmax: int | None = None,
    length: float | None = None,
    weight: float | None = None,
    ppot: float | None = None,
    cpot: float | None = None,
    t0: float | None = None,
    t1: float | None = None,
    niter: int | None = None,
    fod: str | None = None,
    noapo: bool = False,
    fiso: str | None = None,
    eext: str | None = None,
    etrend: str | None = None,
    balance: float | None = None,
    density: float | None = None,
    prob: list[float] | None = None,
    beta: float | None = None,
    lambda_: float | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[TckglobalConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> TckglobalOutputs:
    """
    Multi-Shell Multi-Tissue Global Tractography.
    
    This command will reconstruct the global white matter fibre tractogram that
    best explains the input DWI data, using a multi-tissue spherical convolution
    model.
    
    Example use:
    
    $ tckglobal dwi.mif wmr.txt -riso csfr.txt -riso gmr.txt -mask mask.mif
    -niter 1e9 -fod fod.mif -fiso fiso.mif tracks.tck
    
    in which dwi.mif is the input image, wmr.txt is an anisotropic, multi-shell
    response function for WM, and csfr.txt and gmr.txt are isotropic response
    functions for CSF and GM. The output tractogram is saved to tracks.tck.
    Optional output images fod.mif and fiso.mif contain the predicted WM fODF
    and isotropic tissue fractions of CSF and GM respectively, estimated as part
    of the global optimization and thus affected by spatial regularization.
    
    References:
    
    Christiaens, D.; Reisert, M.; Dhollander, T.; Sunaert, S.; Suetens, P. &
    Maes, F. Global tractography of multi-shell diffusion-weighted imaging data
    using a multi-tissue model. NeuroImage, 2015, 123, 89-101.
    
    Author: Daan Christiaens (daan.christiaens@kcl.ac.uk)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/tckglobal.html
    
    Args:
        source: the image containing the raw DWI data.
        response: the response of a track segment on the DWI signal.
        tracks: the output file containing the tracks generated.
        grad: specify the diffusion encoding scheme (required if not supplied\
            in the header).
        mask: only reconstruct the tractogram within the specified brain mask\
            image.
        riso: set one or more isotropic response functions. (multiple allowed).
        lmax: set the maximum harmonic order for the output series. (default =\
            8).
        length: set the length of the particles (fibre segments). (default =\
            1mm).
        weight: set the weight by which particles contribute to the model.\
            (default = 0.1).
        ppot: set the particle potential, i.e., the cost of adding one segment,\
            relative to the particle weight. (default = 0.05).
        cpot: set the connection potential, i.e., the energy term that drives\
            two segments together. (default = 0.5).
        t0: set the initial temperature of the metropolis hastings optimizer.\
            (default = 0.1).
        t1: set the final temperature of the metropolis hastings optimizer.\
            (default = 0.001).
        niter: set the number of iterations of the metropolis hastings\
            optimizer. (default = 10M).
        fod: Predicted fibre orientation distribution function (fODF).\
            This fODF is estimated as part of the global track optimization,\
            and therefore incorporates the spatial regularization that it\
            imposes. Internally, the fODF is represented as a discrete sum of\
            apodized point spread functions (aPSF) oriented along the\
            directions of all particles in the voxel, used to predict the DWI\
            signal from the particle configuration.
        noapo: disable spherical convolution of fODF with apodized PSF, to\
            output a sum of delta functions rather than a sum of aPSFs.
        fiso: Predicted isotropic fractions of the tissues for which response\
            functions were provided with -riso. Typically, these are CSF and GM.
        eext: Residual external energy in every voxel.
        etrend: internal and external energy trend and cooling statistics.
        balance: balance internal and external energy. (default = 0)\
            Negative values give more weight to the internal energy, positive\
            to the external energy.
        density: set the desired density of the free Poisson process. (default\
            = 1).
        prob: set the probabilities of generating birth, death, randshift,\
            optshift and connect proposals respectively. (default =\
            0.25,0.05,0.25,0.1,0.35).
        beta: set the width of the Hanning interpolation window. (in [0, 1],\
            default = 0)\
            If used, a mask is required, and this mask must keep at least one\
            voxel distance to the image bounding box.
        lambda_: set the weight of the internal energy directly. (default = 1)\
            If provided, any value of -balance will be ignored.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TckglobalOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TCKGLOBAL_METADATA)
    cargs = []
    cargs.append("tckglobal")
    if grad is not None:
        cargs.extend([
            "-grad",
            execution.input_file(grad)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if riso is not None:
        cargs.extend([a for c in [s.run(execution) for s in riso] for a in c])
    if lmax is not None:
        cargs.extend([
            "-lmax",
            str(lmax)
        ])
    if length is not None:
        cargs.extend([
            "-length",
            str(length)
        ])
    if weight is not None:
        cargs.extend([
            "-weight",
            str(weight)
        ])
    if ppot is not None:
        cargs.extend([
            "-ppot",
            str(ppot)
        ])
    if cpot is not None:
        cargs.extend([
            "-cpot",
            str(cpot)
        ])
    if t0 is not None:
        cargs.extend([
            "-t0",
            str(t0)
        ])
    if t1 is not None:
        cargs.extend([
            "-t1",
            str(t1)
        ])
    if niter is not None:
        cargs.extend([
            "-niter",
            str(niter)
        ])
    if fod is not None:
        cargs.extend([
            "-fod",
            fod
        ])
    if noapo:
        cargs.append("-noapo")
    if fiso is not None:
        cargs.extend([
            "-fiso",
            fiso
        ])
    if eext is not None:
        cargs.extend([
            "-eext",
            eext
        ])
    if etrend is not None:
        cargs.extend([
            "-etrend",
            etrend
        ])
    if balance is not None:
        cargs.extend([
            "-balance",
            str(balance)
        ])
    if density is not None:
        cargs.extend([
            "-density",
            str(density)
        ])
    if prob is not None:
        cargs.extend([
            "-prob",
            *map(str, prob)
        ])
    if beta is not None:
        cargs.extend([
            "-beta",
            str(beta)
        ])
    if lambda_ is not None:
        cargs.extend([
            "-lambda",
            str(lambda_)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(source))
    cargs.append(execution.input_file(response))
    cargs.append(tracks)
    ret = TckglobalOutputs(
        root=execution.output_file("."),
        tracks=execution.output_file(tracks),
        fod=execution.output_file(fod) if (fod is not None) else None,
        fiso=execution.output_file(fiso) if (fiso is not None) else None,
        eext=execution.output_file(eext) if (eext is not None) else None,
        etrend=execution.output_file(etrend) if (etrend is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TCKGLOBAL_METADATA",
    "TckglobalConfig",
    "TckglobalOutputs",
    "TckglobalRiso",
    "tckglobal",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__GET_AFNI_ID_METADATA = Metadata(
    id="1911f86812e4cfffdcd0ca8b994f0db28b17e895.boutiques",
    name="@GetAfniID",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VGetAfniIdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__get_afni_id(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    unique_id: OutputPathType
    """Unique identifier of the dataset"""


def v__get_afni_id(
    dset: InputPathType,
    runner: Runner | None = None,
) -> VGetAfniIdOutputs:
    """
    Returns the unique identifier of a dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@GetAfniID.html
    
    Args:
        dset: Dataset for which the unique identifier is to be returned.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VGetAfniIdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__GET_AFNI_ID_METADATA)
    cargs = []
    cargs.append("GetAfniID")
    cargs.append(execution.input_file(dset))
    ret = VGetAfniIdOutputs(
        root=execution.output_file("."),
        unique_id=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VGetAfniIdOutputs",
    "V__GET_AFNI_ID_METADATA",
    "v__get_afni_id",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ALLINEATE_METADATA = Metadata(
    id="2805815dd8dbceb7916da4052ea862dc05a5fa87.boutiques",
    name="3dAllineate",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAllineateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_allineate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_brik: OutputPathType
    """Output dataset brick file"""
    out_head: OutputPathType
    """Output dataset head file"""
    out_param_save: OutputPathType
    """File holding saved warp parameters"""
    out_matrix_save: OutputPathType
    """File holding saved matrix transformations"""


def v_3d_allineate(
    source: InputPathType,
    prefix: str,
    base: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dAllineateOutputs:
    """
    Program to align one dataset (the 'source') to a 'base' dataset using an affine
    (matrix) transformation of space.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dAllineate.html
    
    Args:
        source: Source dataset file.
        prefix: Output prefix.
        base: Base dataset file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAllineateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ALLINEATE_METADATA)
    cargs = []
    cargs.append("3dAllineate")
    cargs.append(execution.input_file(source))
    if base is not None:
        cargs.extend([
            "-base",
            execution.input_file(base)
        ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.append("[OPTIONS]")
    ret = V3dAllineateOutputs(
        root=execution.output_file("."),
        out_brik=execution.output_file(prefix + "+orig.BRIK"),
        out_head=execution.output_file(prefix + "+orig.HEAD"),
        out_param_save=execution.output_file("[1DPARAM_SAVE]"),
        out_matrix_save=execution.output_file("[1DMATRIX_SAVE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAllineateOutputs",
    "V_3D_ALLINEATE_METADATA",
    "v_3d_allineate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLVBM_2_TEMPLATE_METADATA = Metadata(
    id="07d5c99b1fc70d604c474ae66a112235c4703c8a.boutiques",
    name="fslvbm_2_template",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Fslvbm2TemplateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslvbm_2_template(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fslvbm_2_template(
    arch: str | None = None,
    coprocessor: str | None = None,
    coprocessor_multi: str | None = None,
    coprocessor_class: str | None = None,
    coprocessor_toolkit: str | None = None,
    jobhold: str | None = None,
    array_hold: str | None = None,
    logdir: str | None = None,
    mailoptions: str | None = None,
    mailto: str | None = None,
    name: str | None = None,
    priority: str | None = None,
    queue_: str | None = None,
    resource_: str | None = None,
    delete_job: str | None = None,
    memory_gb: float | None = None,
    array_task: str | None = None,
    array_native: str | None = None,
    num_tasks: float | None = None,
    coprocessor_name: str | None = None,
    project: str | None = None,
    runtime_limit: float | None = None,
    job_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> Fslvbm2TemplateOutputs:
    """
    FSL-VBM is a Voxel-Based Morphometry style analysis tool for FSL.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FSLVBM
    
    Args:
        arch: Specify architecture.
        coprocessor: Specify coprocessor type.
        coprocessor_multi: Specify multiple coprocessors.
        coprocessor_class: Specify coprocessor class.
        coprocessor_toolkit: Specify coprocessor toolkit.
        jobhold: Hold job until specified job ID is completed.
        array_hold: Hold array job until specified job ID is completed.
        logdir: Specify log directory.
        mailoptions: Specify mail options.
        mailto: Specify email address for notifications.
        name: Specify job name.
        priority: Specify job priority.
        queue_: Specify queue.
        resource_: Specify resources.
        delete_job: Delete specified job.
        memory_gb: Specify memory in GB.
        array_task: Specify array task.
        array_native: Specify array native task.
        num_tasks: Specify number of tasks.
        coprocessor_name: Specify coprocessor name.
        project: Specify project.
        runtime_limit: Specify runtime limit in minutes.
        job_file: Specify job script file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fslvbm2TemplateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLVBM_2_TEMPLATE_METADATA)
    cargs = []
    cargs.append("fslvbm_2_template")
    if arch is not None:
        cargs.extend([
            "-a",
            arch
        ])
    if coprocessor is not None:
        cargs.extend([
            "-c",
            coprocessor
        ])
    if coprocessor_multi is not None:
        cargs.extend([
            "--coprocessor_multi",
            coprocessor_multi
        ])
    if coprocessor_class is not None:
        cargs.extend([
            "--coprocessor_class",
            coprocessor_class
        ])
    if coprocessor_toolkit is not None:
        cargs.extend([
            "--coprocessor_toolkit",
            coprocessor_toolkit
        ])
    if jobhold is not None:
        cargs.extend([
            "-j",
            jobhold
        ])
    if array_hold is not None:
        cargs.extend([
            "--array_hold",
            array_hold
        ])
    if logdir is not None:
        cargs.extend([
            "-l",
            logdir
        ])
    if mailoptions is not None:
        cargs.extend([
            "-m",
            mailoptions
        ])
    if mailto is not None:
        cargs.extend([
            "-M",
            mailto
        ])
    if name is not None:
        cargs.extend([
            "-N",
            name
        ])
    if priority is not None:
        cargs.extend([
            "-p",
            priority
        ])
    if queue_ is not None:
        cargs.extend([
            "-q",
            queue_
        ])
    if resource_ is not None:
        cargs.extend([
            "-r",
            resource_
        ])
    if delete_job is not None:
        cargs.extend([
            "--delete_job",
            delete_job
        ])
    if memory_gb is not None:
        cargs.extend([
            "-R",
            str(memory_gb)
        ])
    cargs.append("[PARALLELENV]")
    cargs.append("[THREADS]")
    if array_task is not None:
        cargs.extend([
            "-t",
            array_task
        ])
    if array_native is not None:
        cargs.extend([
            "--array_native",
            array_native
        ])
    if num_tasks is not None:
        cargs.extend([
            "-x",
            str(num_tasks)
        ])
    if coprocessor_name is not None:
        cargs.extend([
            "--has_coprocessor",
            coprocessor_name
        ])
    if project is not None:
        cargs.extend([
            "--project",
            project
        ])
    if runtime_limit is not None:
        cargs.extend([
            "-T",
            str(runtime_limit)
        ])
    if job_file is not None:
        cargs.extend([
            "-z",
            execution.input_file(job_file)
        ])
    ret = Fslvbm2TemplateOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLVBM_2_TEMPLATE_METADATA",
    "Fslvbm2TemplateOutputs",
    "fslvbm_2_template",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_SUB_CONFIG_METADATA = Metadata(
    id="3b3de08dcd5e5833bd8d4dae3144cd6e7d370567.boutiques",
    name="fsl_sub_config",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslSubConfigOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_sub_config(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsl_sub_config(
    cluster_system: typing.Literal["shell", "sge", "slurm"],
    help_flag: bool = False,
    runner: Runner | None = None,
) -> FslSubConfigOutputs:
    """
    FSL cluster submission configuration examples.
    
    Author: FMRIB Software Library (FSL)
    
    Args:
        cluster_system: Choice of cluster system configuration example to\
            output. Options are 'shell', 'sge', or 'slurm'.
        help_flag: Show help message and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslSubConfigOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_SUB_CONFIG_METADATA)
    cargs = []
    cargs.append("fsl_sub_config")
    cargs.append(cluster_system)
    if help_flag:
        cargs.append("-h")
    ret = FslSubConfigOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_SUB_CONFIG_METADATA",
    "FslSubConfigOutputs",
    "fsl_sub_config",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_LRFLIP_METADATA = Metadata(
    id="c3f6b742b4b8f6c12d86c2d85c9ab1073114c0a3.boutiques",
    name="3dLRflip",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dLrflipOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_lrflip(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    flipped_output: OutputPathType | None
    """Output dataset after flipping"""


def v_3d_lrflip(
    datasets: list[InputPathType],
    flip_z: bool = False,
    output_prefix: str | None = None,
    runner: Runner | None = None,
) -> V3dLrflipOutputs:
    """
    Flips the rows of a dataset along one of the three axes to correct dataset
    direction labeling errors.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dLRflip.html
    
    Args:
        datasets: Datasets to flip.
        flip_z: Flip about the 3rd direction.
        output_prefix: Prefix to use for output. If multiple datasets are\
            input, the program will choose a prefix for each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dLrflipOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_LRFLIP_METADATA)
    cargs = []
    cargs.append("3dLRflip")
    if flip_z:
        cargs.append("-Z")
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    cargs.extend([execution.input_file(f) for f in datasets])
    ret = V3dLrflipOutputs(
        root=execution.output_file("."),
        flipped_output=execution.output_file(output_prefix + "*") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dLrflipOutputs",
    "V_3D_LRFLIP_METADATA",
    "v_3d_lrflip",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EASYTHRESH_METADATA = Metadata(
    id="32b5ee8e8b0a64ace7242c55a2fa378fc76a967b.boutiques",
    name="easythresh",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class EasythreshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `easythresh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_thresh_image: OutputPathType
    """Output thresholded image"""


def easythresh(
    raw_zstat_input: InputPathType,
    brain_mask_input: InputPathType,
    cluster_z_thresh_input: float,
    cluster_prob_thresh_input: float,
    background_image_input: InputPathType,
    output_root: str,
    mm_flag: bool = False,
    runner: Runner | None = None,
) -> EasythreshOutputs:
    """
    Cluster-based statistical thresholding tool from FSL.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Easythresh
    
    Args:
        raw_zstat_input: Input raw z-statistics image.
        brain_mask_input: Brain mask image.
        cluster_z_thresh_input: Cluster z-threshold.
        cluster_prob_thresh_input: Cluster probability threshold.
        background_image_input: Background image for thresholding.
        output_root: Root of output file names.
        mm_flag: Flag to indicate the use of mm (millimeters).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EasythreshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EASYTHRESH_METADATA)
    cargs = []
    cargs.append("easythresh")
    cargs.append(execution.input_file(raw_zstat_input))
    cargs.append(execution.input_file(brain_mask_input))
    cargs.append(str(cluster_z_thresh_input))
    cargs.append(str(cluster_prob_thresh_input))
    cargs.append(execution.input_file(background_image_input))
    cargs.append(output_root)
    if mm_flag:
        cargs.append("--mm")
    ret = EasythreshOutputs(
        root=execution.output_file("."),
        output_thresh_image=execution.output_file(output_root + "_thresh.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EASYTHRESH_METADATA",
    "EasythreshOutputs",
    "easythresh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_MRS_PREPROC_METADATA = Metadata(
    id="0f0110662e5f9a2d36ffc142dea1f2713f975785.boutiques",
    name="fsl_mrs_preproc",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslMrsPreprocOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_mrs_preproc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_folder: OutputPathType
    """Output folder containing preprocessed data"""


def fsl_mrs_preproc(
    data: InputPathType,
    reference: InputPathType,
    output: str,
    quant: InputPathType | None = None,
    ecc: InputPathType | None = None,
    noaverage: bool = False,
    hlsvd: bool = False,
    leftshift: float | None = None,
    t1: InputPathType | None = None,
    verbose: bool = False,
    conjugate: bool = False,
    overwrite: bool = False,
    report: bool = False,
    config: InputPathType | None = None,
    runner: Runner | None = None,
) -> FslMrsPreprocOutputs:
    """
    FSL Magnetic Resonance Spectroscopy - Complete non-edited SVS Preprocessing.
    
    Author: FMRIB Analysis Group, Oxford University
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FSL
    
    Args:
        data: Input file(s).
        reference: Reference non-water suppressed file.
        output: Output folder.
        quant: Water reference data for quantification (Optional).
        ecc: Water reference data for eddy current correction (Optional).
        noaverage: Do not average repetitions.
        hlsvd: Apply HLSVD for residual water removal.
        leftshift: Remove points at the start of the fid.
        t1: Structural image (for report).
        verbose: Spit out verbose info.
        conjugate: Apply conjugate to FID.
        overwrite: Overwrite existing output folder.
        report: Generate report in output folder.
        config: Configuration file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslMrsPreprocOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_MRS_PREPROC_METADATA)
    cargs = []
    cargs.append("fsl_mrs_preproc")
    cargs.append(execution.input_file(data))
    cargs.append(execution.input_file(reference))
    cargs.append(output)
    if quant is not None:
        cargs.append(execution.input_file(quant))
    if ecc is not None:
        cargs.append(execution.input_file(ecc))
    if noaverage:
        cargs.append("--noaverage")
    if hlsvd:
        cargs.append("--hlsvd")
    if leftshift is not None:
        cargs.extend([
            "--leftshift",
            str(leftshift)
        ])
    if t1 is not None:
        cargs.append(execution.input_file(t1))
    if verbose:
        cargs.append("--verbose")
    if conjugate:
        cargs.append("--conjugate")
    if overwrite:
        cargs.append("--overwrite")
    if report:
        cargs.append("--report")
    if config is not None:
        cargs.append(execution.input_file(config))
    ret = FslMrsPreprocOutputs(
        root=execution.output_file("."),
        output_folder=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_MRS_PREPROC_METADATA",
    "FslMrsPreprocOutputs",
    "fsl_mrs_preproc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TSPLOT_METADATA = Metadata(
    id="9b69e33c8f61f1146dbcc656dc580d78c80db650.boutiques",
    name="tsplot",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class TsplotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tsplot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    timeseries_output: OutputPathType | None
    """Output timeseries data"""


def tsplot(
    input_directory: str,
    main_filtered_data: InputPathType | None = None,
    coordinates: list[float] | None = None,
    coordinates_output: list[float] | None = None,
    mask: InputPathType | None = None,
    output_directory: str | None = None,
    no_weight_flag: bool = False,
    prewhiten_flag: bool = False,
    no_raw_flag: bool = False,
    runner: Runner | None = None,
) -> TsplotOutputs:
    """
    Time series plotting tool for FSL.
    
    Author: FMRIB
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/tsplot
    
    Args:
        input_directory: Input FEAT directory (e.g. feat_directory.feat).
        main_filtered_data: Input main filtered data, in case it's not\
            <feat_directory.feat>/filtered_func_data.
        coordinates: Use X, Y, Z instead of max Z stat position.
        coordinates_output: Use X,Y,Z to output time series only - no stats or\
            modelling.
        mask: Use mask image instead of thresholded activation images.
        output_directory: Change output directory from default of input FEAT\
            directory.
        no_weight_flag: Don't weight cluster averaging with Z stats.
        prewhiten_flag: Prewhiten data and model timeseries before plotting.
        no_raw_flag: Don't keep raw data text files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TsplotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TSPLOT_METADATA)
    cargs = []
    cargs.append("tsplot")
    cargs.append(input_directory)
    if main_filtered_data is not None:
        cargs.extend([
            "-f",
            execution.input_file(main_filtered_data)
        ])
    if coordinates is not None:
        cargs.extend([
            "-c",
            *map(str, coordinates)
        ])
    if coordinates_output is not None:
        cargs.extend([
            "-C",
            *map(str, coordinates_output)
        ])
    if mask is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask)
        ])
    if output_directory is not None:
        cargs.extend([
            "-o",
            output_directory
        ])
    if no_weight_flag:
        cargs.append("-n")
    if prewhiten_flag:
        cargs.append("-p")
    if no_raw_flag:
        cargs.append("-d")
    ret = TsplotOutputs(
        root=execution.output_file("."),
        timeseries_output=execution.output_file(output_directory + "/timeseries.txt") if (output_directory is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TSPLOT_METADATA",
    "TsplotOutputs",
    "tsplot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_RETINO_MAP_METADATA = Metadata(
    id="6301d3d7b1303735f00712af4498f12f7c0c05f4.boutiques",
    name="SurfRetinoMap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfRetinoMapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_retino_map(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    vfr_output: OutputPathType
    """Output Visual Field Ratio (VFR) dataset."""
    threshold_max_output: OutputPathType
    """Maximum threshold at each node in the input datasets."""


def surf_retino_map(
    surface: str,
    polar: str,
    eccentricity: str,
    runner: Runner | None = None,
) -> SurfRetinoMapOutputs:
    """
    Tool for retinotopic mapping on cortical surfaces.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfRetinoMap.html
    
    Args:
        surface: Surface on which distances are computed. See 'Specifying input\
            surfaces' section for syntax.
        polar: Retinotopic dataset: polar angle dataset.
        eccentricity: Retinotopic dataset: eccentricity angle dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfRetinoMapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_RETINO_MAP_METADATA)
    cargs = []
    cargs.append("SurfRetinoMap")
    cargs.append(surface)
    cargs.append("-input")
    cargs.append(polar)
    cargs.append(eccentricity)
    cargs.append("[--prefix")
    cargs.append("PREFIX]")
    cargs.append("[--node_dbg")
    cargs.append("NODE]")
    ret = SurfRetinoMapOutputs(
        root=execution.output_file("."),
        vfr_output=execution.output_file("[PREFIX]_VFR.nii.gz"),
        threshold_max_output=execution.output_file("[PREFIX]_threshold_max.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_RETINO_MAP_METADATA",
    "SurfRetinoMapOutputs",
    "surf_retino_map",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TAGALIGN_METADATA = Metadata(
    id="3a36837ea87f9f5e5e1558ec63e13590efe2e614.boutiques",
    name="3dTagalign",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTagalignOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tagalign(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset_head: OutputPathType | None
    """Output dataset in AFNI format (.HEAD)"""
    output_dataset_brick: OutputPathType | None
    """Output dataset in AFNI format (.BRIK)"""
    output_matvec_file: OutputPathType | None
    """Output transformation matrix and vector file"""


def v_3d_tagalign(
    master_dataset: InputPathType,
    input_dataset: InputPathType,
    tagset_file: InputPathType | None = None,
    no_keep_tags: bool = False,
    matvec_file: str | None = None,
    rotate: bool = False,
    affine: bool = False,
    rotscl: bool = False,
    prefix: str | None = None,
    verbose: bool = False,
    dummy: bool = False,
    runner: Runner | None = None,
) -> V3dTagalignOutputs:
    """
    Rotates/translates dataset 'dset' to be aligned with the master using the
    tagsets embedded in their .HEAD files.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dTagalign.html
    
    Args:
        master_dataset: Use dataset 'mset' as the master dataset. This option\
            is mandatory.
        input_dataset: Input dataset to align.
        tagset_file: Use the tagset in the .tag file instead of dset.
        no_keep_tags: Don't put transformed locations of dset's tags into the\
            output dataset [default = keep tags].
        matvec_file: Write the matrix+vector transformation to file 'mfile'.\
            This can be used with 3dWarp's '-matvec_in2out' option to align other\
            datasets in the same way (e.g., functional datasets).
        rotate: Compute the transformation as a rotation + shift (default).
        affine: Compute the transformation as a general affine map, where the\
            matrix is a general 3x3 matrix.
        rotscl: Compute transformation as a rotation times an isotropic\
            scaling; where matrix is an orthogonal matrix times a scalar.
        prefix: Specify the prefix for the output dataset.
        verbose: Print progress reports.
        dummy: Don't actually rotate the dataset, just compute the\
            transformation matrix and vector. If '-matvec' is used, the mfile will\
            be written.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTagalignOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TAGALIGN_METADATA)
    cargs = []
    cargs.append("3dTagalign")
    cargs.extend([
        "-master",
        execution.input_file(master_dataset)
    ])
    if tagset_file is not None:
        cargs.extend([
            "-tagset",
            execution.input_file(tagset_file)
        ])
    if no_keep_tags:
        cargs.append("-nokeeptags")
    if matvec_file is not None:
        cargs.extend([
            "-matvec",
            matvec_file
        ])
    if rotate:
        cargs.append("-rotate")
    if affine:
        cargs.append("-affine")
    if rotscl:
        cargs.append("-rotscl")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if verbose:
        cargs.append("-verb")
    if dummy:
        cargs.append("-dummy")
    cargs.append("[INTERPOLATION_METHOD]")
    cargs.append(execution.input_file(input_dataset))
    ret = V3dTagalignOutputs(
        root=execution.output_file("."),
        output_dataset_head=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
        output_dataset_brick=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
        output_matvec_file=execution.output_file(matvec_file) if (matvec_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTagalignOutputs",
    "V_3D_TAGALIGN_METADATA",
    "v_3d_tagalign",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_FLIP_NORMALS_METADATA = Metadata(
    id="4435a2734d7103caa7988672c849cb2be5c821f0.boutiques",
    name="surface-flip-normals",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceFlipNormalsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_flip_normals(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """the output surface"""


def surface_flip_normals(
    surface: InputPathType,
    surface_out: str,
    runner: Runner | None = None,
) -> SurfaceFlipNormalsOutputs:
    """
    Flip all tiles on a surface.
    
    Flips all triangles on a surface, resulting in surface normals being flipped
    the other direction (inward vs outward). If you transform a surface with an
    affine that has negative determinant, or a warpfield that similarly flips
    the surface, you may end up with a surface that has normals pointing
    inwards, which may have display problems. Using this command will solve that
    problem.
    
    Author: Washington University School of Medicin
    
    Args:
        surface: the surface to flip the normals of.
        surface_out: the output surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceFlipNormalsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_FLIP_NORMALS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-flip-normals")
    cargs.append(execution.input_file(surface))
    cargs.append(surface_out)
    ret = SurfaceFlipNormalsOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(surface_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_FLIP_NORMALS_METADATA",
    "SurfaceFlipNormalsOutputs",
    "surface_flip_normals",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_GROUP_IN_CORR_METADATA = Metadata(
    id="67d139f33261f26102f0eb19ee1a1d050c9566d3.boutiques",
    name="3dGroupInCorr",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dGroupInCorrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_group_in_corr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Results from analysis"""


def v_3d_group_in_corr(
    set_a: InputPathType,
    set_b: InputPathType | None = None,
    apair: bool = False,
    label_a: str | None = None,
    label_b: str | None = None,
    pooled: bool = False,
    unpooled: bool = False,
    paired: bool = False,
    nosix: bool = False,
    covariates_file: InputPathType | None = None,
    center: str | None = None,
    seed_radius: float | None = None,
    sendall: bool = False,
    donocov: bool = False,
    dospcov: bool = False,
    cluster: str | None = None,
    read: bool = False,
    ztest: bool = False,
    ah: str | None = None,
    port_offset: float | None = None,
    port_offset_quiet: float | None = None,
    port_bloc: float | None = None,
    suma: bool = False,
    quiet: bool = False,
    verbose: bool = False,
    very_verbose: bool = False,
    debug: bool = False,
    batch: str | None = None,
    runner: Runner | None = None,
) -> V3dGroupInCorrOutputs:
    """
    Functional connectivity analysis in group of subjects.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dGroupInCorr.html
    
    Args:
        set_a: Setup file describing the first dataset collection.
        set_b: Setup file describing the second dataset collection for\
            two-sample t-test analysis.
        apair: Use -setA collection again but with different seed locations;\
            produce paired t-test.
        label_a: Label for sub-bricks corresponding to setA.
        label_b: Label for sub-bricks corresponding to setB.
        pooled: Use pooled variance estimator for two-sample un-paired t-test.
        unpooled: Use unpooled variance estimator for two-sample un-paired\
            t-test.
        paired: Use a two-sample paired t-test.
        nosix: Suppress the individual 1-sample t-tests and only return the\
            difference 2-sample t-test.
        covariates_file: File containing covariate values for each dataset.
        center: Option for centering covariates.
        seed_radius: Radius for seed voxel time series averaging (mm).
        sendall: Send all individual subject results to AFNI along with group\
            statistics.
        donocov: Compute results both with and without covariates.
        dospcov: Compute Spearman (rank) correlation coefficient of subject\
            correlation results vs each covariate.
        cluster: Input results from a 3dClustSim run to interface with AFNI.
        read: Force program to read data into memory instead of memory mapping.
        ztest: Debugging option to test if input data is all zero.
        ah: Connect to AFNI/SUMA on a remote host.
        port_offset: Provide a port offset.
        port_offset_quiet: Provide a port offset, with less verbose output.
        port_bloc: Provide a port offset bloc.
        suma: Talk to SUMA instead of AFNI.
        quiet: Suppress informational messages.
        verbose: Print extra informational messages.
        very_verbose: Print even more detailed informational messages.
        debug: Enable internal testing.
        batch: Run program in batch mode with specified METHOD and command\
            file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dGroupInCorrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_GROUP_IN_CORR_METADATA)
    cargs = []
    cargs.append("3dGroupInCorr")
    cargs.extend([
        "-setA",
        execution.input_file(set_a)
    ])
    if set_b is not None:
        cargs.extend([
            "-setB",
            execution.input_file(set_b)
        ])
    if apair:
        cargs.append("-Apair")
    if label_a is not None:
        cargs.extend([
            "-labelA",
            label_a
        ])
    if label_b is not None:
        cargs.extend([
            "-labelB",
            label_b
        ])
    if pooled:
        cargs.append("-pooled")
    if unpooled:
        cargs.append("-unpooled")
    if paired:
        cargs.append("-paired")
    if nosix:
        cargs.append("-nosix")
    if covariates_file is not None:
        cargs.extend([
            "-covariates",
            execution.input_file(covariates_file)
        ])
    if center is not None:
        cargs.extend([
            "-center",
            center
        ])
    if seed_radius is not None:
        cargs.extend([
            "-seedrad",
            str(seed_radius)
        ])
    if sendall:
        cargs.append("-sendall")
    if donocov:
        cargs.append("-donocov")
    if dospcov:
        cargs.append("-dospcov")
    if cluster is not None:
        cargs.extend([
            "-clust",
            cluster
        ])
    if read:
        cargs.append("-read")
    if ztest:
        cargs.append("-ztest")
    if ah is not None:
        cargs.extend([
            "-ah",
            ah
        ])
    if port_offset is not None:
        cargs.extend([
            "-np",
            str(port_offset)
        ])
    if port_offset_quiet is not None:
        cargs.extend([
            "-npq",
            str(port_offset_quiet)
        ])
    if port_bloc is not None:
        cargs.extend([
            "-npb",
            str(port_bloc)
        ])
    if suma:
        cargs.append("-suma")
    if quiet:
        cargs.append("-quiet")
    if verbose:
        cargs.append("-verb")
    if very_verbose:
        cargs.append("-VERB")
    if debug:
        cargs.append("-debug")
    if batch is not None:
        cargs.extend([
            "-batch",
            batch
        ])
    ret = V3dGroupInCorrOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(set_a).name + ".results.nii"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dGroupInCorrOutputs",
    "V_3D_GROUP_IN_CORR_METADATA",
    "v_3d_group_in_corr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DJUNCT_VOL_3SLICE_SELECT_METADATA = Metadata(
    id="14c908b477bccc5760d0b939cfdb6b12f3cc2ce8.boutiques",
    name="@djunct_vol_3slice_select",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDjunctVol3sliceSelectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__djunct_vol_3slice_select(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    ijk_output: OutputPathType
    """File that contains the output indices i j k."""


def v__djunct_vol_3slice_select(
    dataset_file: InputPathType,
    coord_x: float,
    coord_y: float,
    coord_z: float,
    runner: Runner | None = None,
) -> VDjunctVol3sliceSelectOutputs:
    """
    Helper script to convert (x, y, z) coordinates to (i, j, k) indices for a
    dataset. It will return an error if any indices are outside the dataset's
    matrix.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@djunct_vol_3slice_select.html
    
    Args:
        dataset_file: The name of the dataset file.
        coord_x: The x-coordinate in the dataset.
        coord_y: The y-coordinate in the dataset.
        coord_z: The z-coordinate in the dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDjunctVol3sliceSelectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DJUNCT_VOL_3SLICE_SELECT_METADATA)
    cargs = []
    cargs.append("adjunct_vol_3slice_select")
    cargs.append(execution.input_file(dataset_file))
    cargs.append(str(coord_x))
    cargs.append(str(coord_y))
    cargs.append(str(coord_z))
    ret = VDjunctVol3sliceSelectOutputs(
        root=execution.output_file("."),
        ijk_output=execution.output_file("ijk_indices.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDjunctVol3sliceSelectOutputs",
    "V__DJUNCT_VOL_3SLICE_SELECT_METADATA",
    "v__djunct_vol_3slice_select",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

STD2IMGCOORD_METADATA = Metadata(
    id="688ec9ae6fa7e109f9dc1fbdb79eff77f4309cdf.boutiques",
    name="std2imgcoord",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Std2imgcoordOutputs(typing.NamedTuple):
    """
    Output object returned when calling `std2imgcoord(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def std2imgcoord(
    runner: Runner | None = None,
) -> Std2imgcoordOutputs:
    """
    Convert standard space coordinates to image space coordinates.
    
    Author: FMRIB Centre
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Std2imgcoordOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(STD2IMGCOORD_METADATA)
    cargs = []
    cargs.append("std2imgcoord")
    cargs.append("[OPTIONS]")
    cargs.append("<FILENAME_COORDINATES>")
    ret = Std2imgcoordOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "STD2IMGCOORD_METADATA",
    "Std2imgcoordOutputs",
    "std2imgcoord",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TRANSFORMCOMPOSE_METADATA = Metadata(
    id="4a1fa00a64521e89c78077507af058c9f9ff7feb.boutiques",
    name="transformcompose",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class TransformcomposeConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class TransformcomposeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `transformcompose(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def transformcompose(
    input_: list[InputPathType],
    output: str,
    template: InputPathType | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[TransformcomposeConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> TransformcomposeOutputs:
    """
    Compose any number of linear transformations and/or warps into a single
    transformation.
    
    Any linear transforms must be supplied as a 4x4 matrix in a text file (e.g.
    as per the output of mrregister). Any warp fields must be supplied as a 4D
    image representing a deformation field (e.g. as output from mrrregister
    -nl_warp).
    
    Input transformations should be provided to the command in the order in
    which they would be applied to an image if they were to be applied
    individually.
    
    If all input transformations are linear, and the -template option is not
    provided, then the file output by the command will also be a linear
    transformation saved as a 4x4 matrix in a text file. If a template image is
    supplied, then the output will always be a deformation field. If at least
    one of the inputs is a warp field, then the output will be a deformation
    field, which will be defined on the grid of the last input warp image
    supplied if the -template option is not used.
    
    References:
    
    .
    
    Author: David Raffelt (david.raffelt@florey.edu.au)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/transformcompose.html
    
    Args:
        input_: the input transforms (either linear or non-linear warps).
        output: the output file (may be a linear transformation text file, or a\
            deformation warp field image, depending on usage).
        template: define the output grid defined by a template image.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TransformcomposeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TRANSFORMCOMPOSE_METADATA)
    cargs = []
    cargs.append("transformcompose")
    if template is not None:
        cargs.extend([
            "-template",
            execution.input_file(template)
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.extend([execution.input_file(f) for f in input_])
    cargs.append(output)
    ret = TransformcomposeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TRANSFORMCOMPOSE_METADATA",
    "TransformcomposeConfig",
    "TransformcomposeOutputs",
    "transformcompose",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FABBER_DSC_METADATA = Metadata(
    id="f0e99d5d1d58cbb5fed7da548eb3a03fb5be1e2e.boutiques",
    name="fabber_dsc",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FabberDscOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fabber_dsc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    paramnames_file: OutputPathType
    """Parameter names output file"""
    model_fit_file: OutputPathType
    """Model fit output file"""
    residuals_file: OutputPathType
    """Residuals output file"""
    model_extras_file: OutputPathType
    """Model extras output file"""
    mvn_file: OutputPathType
    """MVN distributions output file"""
    mean_file: OutputPathType
    """Parameter means output file"""
    std_file: OutputPathType
    """Parameter standard deviations output file"""
    var_file: OutputPathType
    """Parameter variances output file"""
    zstat_file: OutputPathType
    """Parameter Zstats output file"""
    noise_mean_file: OutputPathType
    """Noise means output file"""
    noise_std_file: OutputPathType
    """Noise standard deviations output file"""
    free_energy_file: OutputPathType
    """Free energy output file"""


def fabber_dsc(
    runner: Runner | None = None,
) -> FabberDscOutputs:
    """
    A flexible model fitting and Bayesian inference tool for fMRI data.
    
    Author: FMRIB, University of Oxford
    
    URL: https://fabber.readthedocs.io/
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FabberDscOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FABBER_DSC_METADATA)
    cargs = []
    cargs.append("fabber")
    cargs.append("[OPTIONS]")
    ret = FabberDscOutputs(
        root=execution.output_file("."),
        paramnames_file=execution.output_file("[OUTPUT]/paramnames.txt"),
        model_fit_file=execution.output_file("[OUTPUT]/model_fit.nii.gz"),
        residuals_file=execution.output_file("[OUTPUT]/residuals.nii.gz"),
        model_extras_file=execution.output_file("[OUTPUT]/model_extras.nii.gz"),
        mvn_file=execution.output_file("[OUTPUT]/mvn.nii.gz"),
        mean_file=execution.output_file("[OUTPUT]/mean.nii.gz"),
        std_file=execution.output_file("[OUTPUT]/std.nii.gz"),
        var_file=execution.output_file("[OUTPUT]/var.nii.gz"),
        zstat_file=execution.output_file("[OUTPUT]/zstat.nii.gz"),
        noise_mean_file=execution.output_file("[OUTPUT]/noise_mean.nii.gz"),
        noise_std_file=execution.output_file("[OUTPUT]/noise_std.nii.gz"),
        free_energy_file=execution.output_file("[OUTPUT]/free_energy.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FABBER_DSC_METADATA",
    "FabberDscOutputs",
    "fabber_dsc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ZEROPAD_METADATA = Metadata(
    id="dd740982a38ee3310ad83f304a2f70e43d5230f3.boutiques",
    name="3dZeropad",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dZeropadOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_zeropad(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset_brik: OutputPathType
    """Output dataset (BRIK format)"""
    output_dataset_head: OutputPathType
    """Output dataset (HEAD format)"""


def v_3d_zeropad(
    dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dZeropadOutputs:
    """
    Adds planes of zeros to a dataset (i.e., pads it out). Negative 'add' count
    means to cut a dataset down in size.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dZeropad.html
    
    Args:
        dataset: Input dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dZeropadOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ZEROPAD_METADATA)
    cargs = []
    cargs.append("3dZeropad")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(dataset))
    ret = V3dZeropadOutputs(
        root=execution.output_file("."),
        output_dataset_brik=execution.output_file("[PREFIX]+orig.BRIK"),
        output_dataset_head=execution.output_file("[PREFIX]+orig.HEAD"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dZeropadOutputs",
    "V_3D_ZEROPAD_METADATA",
    "v_3d_zeropad",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_ESTIMATE_FWHM_METADATA = Metadata(
    id="57f1cf3d50223eccac1e8b093a8e04564691f4d4.boutiques",
    name="volume-estimate-fwhm",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class VolumeEstimateFwhmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_estimate_fwhm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def volume_estimate_fwhm(
    volume: InputPathType,
    opt_roi_roivol: InputPathType | None = None,
    opt_subvolume_subvol: str | None = None,
    opt_whole_file: bool = False,
    opt_demean: bool = False,
    runner: Runner | None = None,
) -> VolumeEstimateFwhmOutputs:
    """
    Estimate fwhm smoothness of a volume.
    
    Estimates the smoothness of the input volume in X, Y, and Z directions
    separately, printing the estimates to standard output, in mm as FWHM. If
    -subvolume or -whole-file are not specified, each subvolume is estimated and
    displayed separately.
    
    Author: Washington University School of Medicin
    
    Args:
        volume: the input volume.
        opt_roi_roivol: use only data within an ROI: the volume to use as an\
            ROI.
        opt_subvolume_subvol: select a single subvolume to estimate smoothness\
            of: the subvolume number or name.
        opt_whole_file: estimate for the whole file at once, not each subvolume\
            separately.
        opt_demean: subtract the mean image before estimating smoothness.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeEstimateFwhmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_ESTIMATE_FWHM_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-estimate-fwhm")
    cargs.append(execution.input_file(volume))
    if opt_roi_roivol is not None:
        cargs.extend([
            "-roi",
            execution.input_file(opt_roi_roivol)
        ])
    if opt_subvolume_subvol is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvol
        ])
    if opt_whole_file:
        cargs.append("-whole-file")
    if opt_demean:
        cargs.append("-demean")
    ret = VolumeEstimateFwhmOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_ESTIMATE_FWHM_METADATA",
    "VolumeEstimateFwhmOutputs",
    "volume_estimate_fwhm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONNECTOME2TCK_METADATA = Metadata(
    id="9b8f76e3780a04a62382dbfad738ea0d57198eda.boutiques",
    name="connectome2tck",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Connectome2tckConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Connectome2tckOutputs(typing.NamedTuple):
    """
    Output object returned when calling `connectome2tck(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def connectome2tck(
    tracks_in: InputPathType,
    assignments_in: InputPathType,
    prefix_out: str,
    nodes: list[int] | None = None,
    exclusive: bool = False,
    files: str | None = None,
    exemplars: InputPathType | None = None,
    keep_unassigned: bool = False,
    keep_self: bool = False,
    tck_weights_in: InputPathType | None = None,
    prefix_tck_weights_out: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Connectome2tckConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Connectome2tckOutputs:
    """
    Extract streamlines from a tractogram based on their assignment to parcellated
    nodes.
    
    The compulsory input file "assignments_in" should contain a text file where
    there is one row for each streamline, and each row contains a list of
    numbers corresponding to the parcels to which that streamline was assigned
    (most typically there will be two entries per streamline, one for each
    endpoint; but this is not strictly a requirement). This file will most
    typically be generated using the tck2connectome command with the
    -out_assignments option.
    
    References:
    
    .
    
    Author: Robert E. Smith (robert.smith@florey.edu.au)
    
    URL:
    https://mrtrix.readthedocs.io/en/latest/reference/commands/connectome2tck.html
    
    Args:
        tracks_in: the input track file.
        assignments_in: input text file containing the node assignments for\
            each streamline.
        prefix_out: the output file / prefix.
        nodes: only select tracks that involve a set of nodes of interest\
            (provide as a comma-separated list of integers).
        exclusive: only select tracks that exclusively connect nodes from\
            within the list of nodes of interest.
        files: select how the resulting streamlines will be grouped in output\
            files. Options are: per_edge, per_node, single (default: per_edge).
        exemplars: generate a mean connection exemplar per edge, rather than\
            keeping all streamlines (the parcellation node image must be provided\
            in order to constrain the exemplar endpoints).
        keep_unassigned: by default, the program discards those streamlines\
            that are not successfully assigned to a node. Set this option to\
            generate corresponding outputs containing these streamlines (labelled\
            as node index 0).
        keep_self: by default, the program will not output streamlines that\
            connect to the same node at both ends. Set this option to instead keep\
            these self-connections.
        tck_weights_in: specify a text scalar file containing the streamline\
            weights.
        prefix_tck_weights_out: provide a prefix for outputting a text file\
            corresponding to each output file, each containing only the streamline\
            weights relevant for that track file.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Connectome2tckOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONNECTOME2TCK_METADATA)
    cargs = []
    cargs.append("connectome2tck")
    if nodes is not None:
        cargs.extend([
            "-nodes",
            ",".join(map(str, nodes))
        ])
    if exclusive:
        cargs.append("-exclusive")
    if files is not None:
        cargs.extend([
            "-files",
            files
        ])
    if exemplars is not None:
        cargs.extend([
            "-exemplars",
            execution.input_file(exemplars)
        ])
    if keep_unassigned:
        cargs.append("-keep_unassigned")
    if keep_self:
        cargs.append("-keep_self")
    if tck_weights_in is not None:
        cargs.extend([
            "-tck_weights_in",
            execution.input_file(tck_weights_in)
        ])
    if prefix_tck_weights_out is not None:
        cargs.extend([
            "-prefix_tck_weights_out",
            prefix_tck_weights_out
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(tracks_in))
    cargs.append(execution.input_file(assignments_in))
    cargs.append(prefix_out)
    ret = Connectome2tckOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONNECTOME2TCK_METADATA",
    "Connectome2tckConfig",
    "Connectome2tckOutputs",
    "connectome2tck",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BORDER_RESAMPLE_METADATA = Metadata(
    id="dd380b1e5e4fe1855828015b5097f5b06fb67827.boutiques",
    name="border-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class BorderResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `border_resample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    border_out: OutputPathType
    """the output border file"""


def border_resample(
    border_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    border_out: str,
    runner: Runner | None = None,
) -> BorderResampleOutputs:
    """
    Resample a border file to a different mesh.
    
    Resamples a border file, given two spherical surfaces that are in register.
    Only borders that have the same structure as current-sphere will be
    resampled.
    
    Author: Washington University School of Medicin
    
    Args:
        border_in: the border file to resample.
        current_sphere: a sphere surface with the mesh that the metric is\
            currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        border_out: the output border file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_RESAMPLE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-resample")
    cargs.append(execution.input_file(border_in))
    cargs.append(execution.input_file(current_sphere))
    cargs.append(execution.input_file(new_sphere))
    cargs.append(border_out)
    ret = BorderResampleOutputs(
        root=execution.output_file("."),
        border_out=execution.output_file(border_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BORDER_RESAMPLE_METADATA",
    "BorderResampleOutputs",
    "border_resample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_QUAL_METADATA = Metadata(
    id="c927abddc75e51fcc598c15db923bc25092fa884.boutiques",
    name="SurfQual",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfQualOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_qual(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dist_output: OutputPathType
    """File containing distances of nodes from the surface's center."""
    dist_color_output: OutputPathType
    """Colorized file containing distances of nodes from the surface's
    center."""
    bad_nodes_output: OutputPathType
    """File containing nodes with bad dot product values."""
    bad_nodes_color_output: OutputPathType
    """Colorized file containing nodes with bad dot product values."""
    dotprod_output: OutputPathType
    """File containing dot product values for all nodes."""
    dotprod_color_output: OutputPathType
    """Colorized file containing dot product values for all nodes."""
    intersect_nodes_output: OutputPathType
    """File containing indices of nodes forming segments that intersect the
    surface."""


def surf_qual(
    spec_file: InputPathType,
    surface_a: list[InputPathType],
    runner: Runner | None = None,
) -> SurfQualOutputs:
    """
    A program to check the quality of surfaces.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfQual.html
    
    Args:
        spec_file: Spec file containing input surfaces.
        surface_a: Name of input surface A.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfQualOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_QUAL_METADATA)
    cargs = []
    cargs.append("SurfQual")
    cargs.append("-spec")
    cargs.extend([
        "-spec",
        execution.input_file(spec_file)
    ])
    cargs.extend([
        "-surf_A",
        *[execution.input_file(f) for f in surface_a]
    ])
    cargs.append("-sphere")
    cargs.append("[OPTIONS]")
    ret = SurfQualOutputs(
        root=execution.output_file("."),
        dist_output=execution.output_file("[OUTPREF]_Dist.1D.dset"),
        dist_color_output=execution.output_file("[OUTPREF]_Dist.1D.col"),
        bad_nodes_output=execution.output_file("[OUTPREF]_BadNodes.1D.dset"),
        bad_nodes_color_output=execution.output_file("[OUTPREF]_BadNodes.1D.col"),
        dotprod_output=execution.output_file("[OUTPREF]_dotprod.1D.dset"),
        dotprod_color_output=execution.output_file("[OUTPREF]_dotprod.1D.col"),
        intersect_nodes_output=execution.output_file("[OUTPREF]_IntersNodes.1D.dset"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_QUAL_METADATA",
    "SurfQualOutputs",
    "surf_qual",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_INFO_METADATA = Metadata(
    id="98adb2ab56264228c422fbe7734ffc0681c92698.boutiques",
    name="SurfInfo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metrics_output: OutputPathType
    """Output file containing calculated surface metrics."""


def surf_info(
    surface: InputPathType,
    com: bool = False,
    debug_level: float | None = None,
    detail_level: float | None = None,
    quiet: bool = False,
    separator: str | None = None,
    input_surface: str | None = None,
    surface_state: str | None = None,
    surface_volume: InputPathType | None = None,
    spec_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> SurfInfoOutputs:
    """
    Tool to gather information about surface files.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfInfo.html
    
    Args:
        surface: Input surface file.
        com: Output the center of mass.
        debug_level: Debugging level (2 turns LocalHead ON).
        detail_level: Calculate surface metrics. 1=yes, 0=no.
        quiet: Do not include the name of the parameter in output.
        separator: Use string SEP to separate parameter values. Default is ' ;\
            '.
        input_surface: Specify the input surface type and file.
        surface_state: Specify surface type, state, and name.
        surface_volume: Specify a surface volume file.
        spec_file: Specify a surface specification (spec) file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfInfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_INFO_METADATA)
    cargs = []
    cargs.append("SurfInfo")
    cargs.append("[options]")
    cargs.append(execution.input_file(surface))
    if com:
        cargs.append("-COM")
    if debug_level is not None:
        cargs.extend([
            "-debug",
            str(debug_level)
        ])
    if detail_level is not None:
        cargs.extend([
            "-detail",
            str(detail_level)
        ])
    if quiet:
        cargs.append("-quiet")
    if separator is not None:
        cargs.extend([
            "-sep",
            separator
        ])
    if input_surface is not None:
        cargs.extend([
            "-i_TYPE",
            input_surface
        ])
    if surface_state is not None:
        cargs.extend([
            "-tsn",
            surface_state
        ])
    if surface_volume is not None:
        cargs.extend([
            "-sv",
            execution.input_file(surface_volume)
        ])
    if spec_file is not None:
        cargs.extend([
            "-spec",
            execution.input_file(spec_file)
        ])
    ret = SurfInfoOutputs(
        root=execution.output_file("."),
        metrics_output=execution.output_file(pathlib.Path(surface).name + "_metrics.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_INFO_METADATA",
    "SurfInfoOutputs",
    "surf_info",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FOCI_LIST_COORDS_METADATA = Metadata(
    id="1d1153d544f899101dc7b1ef349276d95203d8ef.boutiques",
    name="foci-list-coords",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class FociListCoordsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `foci_list_coords(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def foci_list_coords(
    foci_file: InputPathType,
    coord_file_out: str,
    opt_names_out_names_file_out: str | None = None,
    runner: Runner | None = None,
) -> FociListCoordsOutputs:
    """
    Output foci coordinates in a text file.
    
    Output the coordinates for every focus in the foci file, and optionally the
    focus names in a second text file.
    
    Author: Washington University School of Medicin
    
    Args:
        foci_file: input foci file.
        coord_file_out: output - the output coordinate text file.
        opt_names_out_names_file_out: output the foci names: output - text file\
            to put foci names in.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FociListCoordsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FOCI_LIST_COORDS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-foci-list-coords")
    cargs.append(execution.input_file(foci_file))
    cargs.append(coord_file_out)
    if opt_names_out_names_file_out is not None:
        cargs.extend([
            "-names-out",
            opt_names_out_names_file_out
        ])
    ret = FociListCoordsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FOCI_LIST_COORDS_METADATA",
    "FociListCoordsOutputs",
    "foci_list_coords",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__RENAME_PANGA_METADATA = Metadata(
    id="51f0ff41c0be1ae9dd7de0ea5bf011309bce0477.boutiques",
    name="@RenamePanga",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VRenamePangaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__rename_panga(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    head_file: OutputPathType | None
    """Main output file (HEAD)"""
    brik_file: OutputPathType | None
    """Main output file (BRIK)"""
    log_file: OutputPathType | None
    """Log file created in the current directory"""


def v__rename_panga(
    dir_number: str,
    first_image_number: str,
    num_slices: float,
    num_reps: float,
    output_root: str,
    keep_prefix: bool = False,
    interactive: bool = False,
    outliers_check: bool = False,
    slice_pattern: str | None = None,
    output_directory: str | None = None,
    runner: Runner | None = None,
) -> VRenamePangaOutputs:
    """
    Creates AFNI bricks from RealTime GE EPI series.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@RenamePanga.html
    
    Args:
        dir_number: The directory number where the first image of the series is\
            stored.
        first_image_number: The number of the first image in the series.
        num_slices: The number of slices making up the imaged volume.
        num_reps: The number of samples in your time series.
        output_root: The prefix for the output brick.
        keep_prefix: Forces @RenamePanga to use the prefix you designate\
            without modification.
        interactive: Launches to3d in interactive mode. This allows you to\
            double check the automated settings.
        outliers_check: Performs outliers check and writes the outliers to a\
            .1D file placed in the output directory.
        slice_pattern: Sets the slice acquisition pattern. The default option\
            is alt+z.
        output_directory: Directory where the output (bricks and 1D files) will\
            be stored. The default directory is ./afni.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VRenamePangaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__RENAME_PANGA_METADATA)
    cargs = []
    cargs.append("@RenamePanga")
    cargs.append(dir_number)
    cargs.append(first_image_number)
    cargs.append(str(num_slices))
    cargs.append(str(num_reps))
    cargs.append(output_root)
    if keep_prefix:
        cargs.append("-kp")
    if interactive:
        cargs.append("-i")
    if outliers_check:
        cargs.append("-oc")
    if slice_pattern is not None:
        cargs.extend([
            "-sp",
            slice_pattern
        ])
    if output_directory is not None:
        cargs.extend([
            "-od",
            output_directory
        ])
    ret = VRenamePangaOutputs(
        root=execution.output_file("."),
        head_file=execution.output_file(output_directory + "/" + output_root + "_r#.HEAD") if (output_directory is not None) else None,
        brik_file=execution.output_file(output_directory + "/" + output_root + "_r#.BRIK") if (output_directory is not None) else None,
        log_file=execution.output_file(output_directory + "/MAPLOG_Panga") if (output_directory is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VRenamePangaOutputs",
    "V__RENAME_PANGA_METADATA",
    "v__rename_panga",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_SUB_METADATA = Metadata(
    id="4a2ab1677f50e399301d58366587c073197f8285.boutiques",
    name="fsl_sub",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslSubOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_sub(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsl_sub(
    runner: Runner | None = None,
) -> FslSubOutputs:
    """
    FSL cluster submission tool.
    
    Author: FMRIB (Oxford University)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FslSub
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslSubOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_SUB_METADATA)
    cargs = []
    cargs.append("fsl_sub")
    cargs.append("[OPTIONS]")
    ret = FslSubOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_SUB_METADATA",
    "FslSubOutputs",
    "fsl_sub",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMAGE_STATS_METADATA = Metadata(
    id="8b0a590062a6a49fc4c40efc1e083385dbf3e12c.boutiques",
    name="image_stats",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ImageStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `image_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_stat: OutputPathType
    """Any value. Stats output."""


def image_stats(
    in_file: InputPathType,
    op_string: str,
    split_4d: bool = False,
    index_mask_file: InputPathType | None = None,
    mask_file: InputPathType | None = None,
    output_type: typing.Literal["NIFTI", "NIFTI_PAIR", "NIFTI_GZ", "NIFTI_PAIR_GZ"] | None = None,
    runner: Runner | None = None,
) -> ImageStatsOutputs:
    """
    Use FSL fslstats command to calculate stats from images.
    
    Author: Nipype (interface)
    
    URL:
    http://www.fmrib.ox.ac.uk/fslcourse/lectures/practicals/intro/index.htm#fslutils
    
    Args:
        in_file: Input file to generate stats of.
        op_string: String defining the operation, options are applied in order,\
            e.g. -m -l 10 -m will report the non-zero mean, apply a threshold and\
            then report the new nonzero mean.
        split_4d: Give a separate output line for each 3d volume of a 4d\
            timeseries.
        index_mask_file: Generate separate n submasks from indexmask, for\
            indexvalues 1..n where n is the maximum index value in indexmask, and\
            generate statistics for each submask.
        mask_file: Mask file used for option -k %s.
        output_type: 'nifti' or 'nifti_pair' or 'nifti_gz' or 'nifti_pair_gz'.\
            Fsl output type.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImageStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMAGE_STATS_METADATA)
    cargs = []
    cargs.append("ImageStats")
    if split_4d:
        cargs.append("-t")
    if index_mask_file is not None:
        cargs.extend([
            "-K",
            execution.input_file(index_mask_file)
        ])
    cargs.append(execution.input_file(in_file))
    cargs.append(op_string)
    if mask_file is not None:
        cargs.append(execution.input_file(mask_file))
    if output_type is not None:
        cargs.append(output_type)
    ret = ImageStatsOutputs(
        root=execution.output_file("."),
        out_stat=execution.output_file("out_stat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMAGE_STATS_METADATA",
    "ImageStatsOutputs",
    "image_stats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLMERGE_METADATA = Metadata(
    id="ef048ed2cfafa159d4abdde743e604efb694c7e4.boutiques",
    name="fslmerge",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslmergeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslmerge(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output concatenated image file"""


def fslmerge(
    output_file: str,
    input_files: list[InputPathType],
    merge_set_tr: bool = False,
    tr_value: float | None = None,
    runner: Runner | None = None,
) -> FslmergeOutputs:
    """
    FSL tool to concatenate images in various dimensions.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils
    
    Args:
        output_file: Output concatenated image file.
        input_files: Input image files to concatenate.
        merge_set_tr: Concatenate images in time and set the output image tr to\
            the provided value.
        tr_value: TR value in seconds, used with the -tr flag.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslmergeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLMERGE_METADATA)
    cargs = []
    cargs.append("fslmerge")
    if merge_set_tr:
        cargs.append("-tr")
    cargs.append(output_file)
    cargs.extend([execution.input_file(f) for f in input_files])
    if tr_value is not None:
        cargs.append(str(tr_value))
    ret = FslmergeOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(output_file + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLMERGE_METADATA",
    "FslmergeOutputs",
    "fslmerge",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_COMBINE_STR_PY_METADATA = Metadata(
    id="5bc025c6de9a8249da89efd8216e74953b3f77ce.boutiques",
    name="adjunct_combine_str.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctCombineStrPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_combine_str_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_selector_file: OutputPathType
    """The output file containing the new string selector"""


def adjunct_combine_str_py(
    output_file: str,
    upper_index: float,
    string_selectors: list[str],
    runner: Runner | None = None,
) -> AdjunctCombineStrPyOutputs:
    """
    A simple helper function for fat_proc* scripts that processes string selectors
    and outputs a new string selector.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/adjunct_combine_str.py.html
    
    Args:
        output_file: An output file name.
        upper_index: An int that is the upper index for the selector (-1 means\
            to use the max number in the input strings).
        string_selectors: One or more string selector strings of *goods* to\
            keep.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctCombineStrPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_COMBINE_STR_PY_METADATA)
    cargs = []
    cargs.append("/opt/afni/src/../install/adjunct_combine_str.py")
    cargs.append(output_file)
    cargs.append(str(upper_index))
    cargs.extend(string_selectors)
    ret = AdjunctCombineStrPyOutputs(
        root=execution.output_file("."),
        output_selector_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_COMBINE_STR_PY_METADATA",
    "AdjunctCombineStrPyOutputs",
    "adjunct_combine_str_py",
]
